diff acelp_vectors.h @ 11462:c2e19a511e26 libavcodec

Fix spelling.
author rbultje
date Thu, 11 Mar 2010 17:42:53 +0000
parents 00fcecde822b
children 26aabf52f578
line wrap: on
line diff
--- a/acelp_vectors.h	Thu Mar 11 10:52:34 2010 +0000
+++ b/acelp_vectors.h	Thu Mar 11 17:42:53 2010 +0000
@@ -212,7 +212,7 @@
                              int length);
 
 /**
  * Adaptative gain control (as used in AMR postfiltering)
  *
  * @param buf_out the input speech buffer
  * @param speech_energ input energy
@@ -220,8 +220,8 @@
  * @param alpha exponential filter factor
  * @param gain_mem a pointer to the filter memory (single float of size)
  */
-void ff_adaptative_gain_control(float *buf_out, float speech_energ,
-                                int size, float alpha, float *gain_mem);
+void ff_adaptive_gain_control(float *buf_out, float speech_energ,
+                              int size, float alpha, float *gain_mem);
 
 /**
  * Set the sum of squares of a signal by scaling
@@ -212,7 +212,7 @@
 
 /**
- * Adaptative gain control (as used in AMR postfiltering)
+ * Adaptive gain control (as used in AMR postfiltering)
  *
  * @param buf_out the input speech buffer